==> pyrate-0.2.5.tar.gz: pyrate-0.2.5/pyrate/services/mailchimp.py <==
import json
from pyrate.main import Pyrate

class MailchimpPyrate(Pyrate):

    # This variable should be set on implementation
    api_key = ''

    http_methods = ['POST']
    default_http_method = http_methods[0]
    return_formats = ['JSON', 'XML', 'PHP']
    default_header_content = {}
    auth_type = 'API_KEY'
    connection_check_method = ('POST', 'helper/ping')

    def __init__(self):
        self.default_http_method = self.http_methods[0]
        self.default_return_format = self.return_formats[0]
        self.base_url = 'https://' + self.api_key[-3:] + '.api.mailchimp.com/2.0/'
        self.default_body_content = {
            'apikey': self.api_key
        }

    def check_response_success(self, response):
        if 'error' not in response:
            if 'errors' in response:
                if response['errors'] == []:
                    return True
                else:
                    return False
            return True
        else:
            self.parse_errors(response)
            return False

    def parse_errors(self, response):
        if 'error' in response:
            print "Error: %s (Code: %s)" % (response['error'], response['code'])
        elif 'errors' in response:
            for error in response['errors']:
                print "Error: %s (Code: %s)" % (error['error'], error['code'])
                print error['param']
        else:
            print "Error: %s" % response

    # http://apidocs.mailchimp.com/api/2.0/lists/list.php
    def getLists(self, filters=None, start=None, limit=None, sort_field=None, sort_dir=None):
        fargs = locals()
        res = self.do('lists/list', http_method='POST', content=self.build_content(fargs))
        if self.check_response_success(res):
            return res['data']
        else:
            return res

    def getListByName(self, list_name):
        lists = self.getLists()
        for l in lists:
            if l['name'] == list_name:
                return l

    # http://apidocs.mailchimp.com/api/2.0/lists/subscribe.php
    def subscribeToList(self, list_name, user_email, merge_vars=None, email_type=None, double_optin=None, update_existing=None,
                        replace_interests=None, send_welcome=None):

        list_id = self.getListByName(list_name)['id']
        fargs = {'id': list_id, 'email': {'email': user_email}, 'merge_vars': merge_vars, 'email_type': email_type,
                 'double_optin': double_optin, 'update_existing': update_existing,
                 'replace_interests': replace_interests, 'send_welcome': send_welcome}

        res = self.do('lists/subscribe', http_method='POST', content=self.build_content(fargs))
        return self.check_response_success(res)

    # http://apidocs.mailchimp.com/api/2.0/lists/unsubscribe.php
    def unsubscribeFromList(self, list_name, user_email, delete_member=None, send_goodbye=None, send_notify=None):
        list_id = self.getListByName(list_name)['id']
        fargs = {'id': list_id, 'email': {'email': user_email}, 'delete_member': delete_member, 'send_goodbye': send_goodbye,
                 'send_notify': send_notify}

        res = self.do('lists/unsubscribe', http_method='POST', content=self.build_content(fargs))
        return self.check_response_success(res)

==> pyrate-0.2.6.tar.gz: pyrate-0.2.6/pyrate/services/mailchimp.py <==
import json
from pyrate.main import Pyrate

class MailchimpPyrate(Pyrate):

    # This variable should be set on implementation
    api_key = ''

    http_methods = ['POST']
    default_http_method = http_methods[0]
    return_formats = ['JSON', 'XML', 'PHP']
    default_header_content = {}
    auth_type = 'API_KEY'
    connection_check_method = ('POST', 'helper/ping')

    def __init__(self):
        self.default_http_method = self.http_methods[0]
        self.default_return_format = self.return_formats[0]
        self.base_url = 'https://' + self.api_key[-3:] + '.api.mailchimp.com/2.0/'
        self.default_body_content = {
            'apikey': self.api_key
        }

    def check_response_success(self, response):
        if 'error' not in response:
            if 'errors' in response:
                if response['errors'] == []:
                    return True
                else:
                    return False
            return True
        else:
            self.parse_errors(response)
            return False

    def parse_errors(self, response):
        if 'error' in response:
            print "Error: %s (Code: %s)" % (response['error'], response['code'])
        elif 'errors' in response:
            for error in response['errors']:
                print "Error: %s (Code: %s)" % (error['error'], error['code'])
                print error['param']
        else:
            print "Error: %s" % response

    # http://apidocs.mailchimp.com/api/2.0/lists/list.php
    def getLists(self, filters=None, start=None, limit=None, sort_field=None, sort_dir=None):
        fargs = locals()
        res = self.do('lists/list', http_method='POST', content=self.build_content(fargs))
        if self.check_response_success(res):
            return res['data']
        else:
            return res

    def getListByName(self, list_name):
        lists = self.getLists()
        for l in lists:
            if l['name'] == list_name:
                return l

    # http://apidocs.mailchimp.com/api/2.0/lists/subscribe.php
    def subscribeToList(self, list_name, user_email, merge_vars=None, email_type=None, double_optin=None, update_existing=None,
                        replace_interests=None, send_welcome=None):

        list_id = self.getListByName(list_name)['id']
        fargs = {'id': list_id, 'email': {'email': user_email}, 'merge_vars': merge_vars, 'email_type': email_type,
                 'double_optin': double_optin, 'update_existing': update_existing,
                 'replace_interests': replace_interests, 'send_welcome': send_welcome}

        return self.do('lists/subscribe', http_method='POST', content=self.build_content(fargs))
        # return self.check_response_success(res)

    # http://apidocs.mailchimp.com/api/2.0/lists/unsubscribe.php
    def unsubscribeFromList(self, list_name, user_email, delete_member=None, send_goodbye=None, send_notify=None):
        list_id = self.getListByName(list_name)['id']
        fargs = {'id': list_id, 'email': {'email': user_email}, 'delete_member': delete_member, 'send_goodbye': send_goodbye,
                 'send_notify': send_notify}

        return self.do('lists/unsubscribe', http_method='POST', content=self.build_content(fargs))
        # return self.check_response_success(res)
